@@ -10,10 +10,8 @@ Pl_Concatenate::Pl_Concatenate(char const* identifier, Pipeline* next) :
     }
 }
 
-Pl_Concatenate::~Pl_Concatenate() // NOLINT (modernize-use-equals-default)
-{
-    // Must be explicit and not inline -- see QPDF_DLL_CLASS in README-maintainer
-}
+// Must be explicit and not inline -- see QPDF_DLL_CLASS in README-maintainer
+Pl_Concatenate::~Pl_Concatenate() = default;
 
 void
 Pl_Concatenate::write(unsigned char const* data, size_t len)
